@@ -1,7 +1,7 @@
 package Bencher::Scenario::SortSub::naturally;
 
 our $DATE = '2017-02-02'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -47,8 +47,8 @@ our $scenario = {
         },
     ],
     datasets => [
-        { name=>'10items' , args=>{data=>[shuffle map { "track$_.mp3" } 1..10 ]} },
-        { name=>'100items', args=>{data=>[shuffle map { "track$_.mp3" } 1..100]} },
+        { name=>'10items' , args=>{data=>[shuffle map { "track$_.mp3" } 1..10 ]} , result=>[map { "track$_.mp3" } 1..10 ]},
+        { name=>'100items', args=>{data=>[shuffle map { "track$_.mp3" } 1..100]} , result=>[map { "track$_.mp3" } 1..100]},
     ],
 };
 
@@ -67,7 +67,7 @@ Bencher::Scenario::SortSub::naturally - Benchmark natural sorting
 
 =head1 VERSION
 
-This document describes version 0.004 of Bencher::Scenario::SortSub::naturally (from Perl distribution Bencher-Scenarios-SortSub), released on 2017-02-02.
+This document describes version 0.005 of Bencher::Scenario::SortSub::naturally (from Perl distribution Bencher-Scenarios-SortSub), released on 2017-02-02.
 
 =head1 SYNOPSIS
 
@@ -172,12 +172,12 @@ Benchmark with default options (C<< bencher -m SortSub::naturally >>):
  +-----------------------------+-----------+-----------+------------+---------+---------+
  | participant                 | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +-----------------------------+-----------+-----------+------------+---------+---------+
- | Sort::Naturally::nsort      |       644 | 1.55      |       1    | 4.3e-07 |      20 |
- | Sort::Key::Natural::natsort |      2070 | 0.483     |       3.21 | 2.1e-07 |      20 |
- | Sort::Naturally::XS::nsort  |      6000 | 0.2       |       9    | 6.7e-06 |      20 |
- | Sort::Sub::naturally        |    231720 | 0.0043156 |     359.54 | 1.2e-11 |      20 |
- | Sort::Naturally::ncmp       |    234000 | 0.00427   |     363    | 1.5e-09 |      24 |
- | Sort::Naturally::XS::ncmp   |    236000 | 0.00424   |     366    | 1.5e-09 |      24 |
+ | Sort::Naturally::nsort      |       578 |  1.73     |        1   | 9.1e-07 |      20 |
+ | Sort::Key::Natural::natsort |      2000 |  0.5      |        3   | 5.9e-06 |      20 |
+ | Sort::Naturally::XS::nsort  |      7950 |  0.126    |       13.8 | 4.7e-08 |      26 |
+ | Sort::Sub::naturally        |    200000 |  0.005    |      400   | 8.4e-08 |      31 |
+ | Sort::Naturally::XS::ncmp   |    233800 |  0.004277 |      404.5 | 4.6e-11 |      20 |
+ | Sort::Naturally::ncmp       |    235000 |  0.00426  |      406   | 1.7e-09 |      20 |
  +-----------------------------+-----------+-----------+------------+---------+---------+
 
  #table2#
@@ -185,27 +185,27 @@ Benchmark with default options (C<< bencher -m SortSub::naturally >>):
  +-----------------------------+-----------+-----------+------------+---------+---------+
  | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-----------------------------+-----------+-----------+------------+---------+---------+
- | Sort::Naturally::nsort      |   14336.6 | 69.7516   |     1      |   0     |      21 |
- | Sort::Key::Natural::natsort |   20700   | 48.4      |     1.44   | 1.3e-08 |      20 |
- | Sort::Naturally::XS::nsort  |  175698   |  5.69157  |    12.2553 |   0     |      21 |
- | Sort::Sub::naturally        | 1780320   |  0.561697 |   124.18   |   0     |      20 |
- | Sort::Naturally::ncmp       | 1780610   |  0.561605 |   124.201  |   0     |      20 |
- | Sort::Naturally::XS::ncmp   | 1793190   |  0.557666 |   125.078  |   0     |      20 |
+ | Sort::Naturally::nsort      |     15000 | 65        |      1     | 1.1e-07 |      20 |
+ | Sort::Key::Natural::natsort |     18000 | 55        |      1.2   |   8e-08 |      20 |
+ | Sort::Naturally::XS::nsort  |    189260 |  5.2838   |     12.278 | 1.2e-11 |      24 |
+ | Sort::Naturally::ncmp       |   1580000 |  0.633    |    103     |   2e-10 |      21 |
+ | Sort::Sub::naturally        |   1768950 |  0.565308 |    114.758 |   0     |      20 |
+ | Sort::Naturally::XS::ncmp   |   1794000 |  0.5576   |    116.4   | 4.1e-11 |      20 |
  +-----------------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m SortSub::naturally --module-startup >>):
 
  #table3#
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | Sort::Key::Natural  | 1.4                          | 4.9                | 19             |      28   |                   22.1 |        1   | 6.6e-05   |      21 |
- | Sort::Naturally::XS | 1.4                          | 4.8                | 19             |      13   |                    7.1 |        2.2 | 3.5e-05   |      20 |
- | Sort::Naturally     | 1.2                          | 4.7                | 16             |      12   |                    6.1 |        2.3 |   0.00012 |      20 |
- | Sort::Sub           | 1.2                          | 4.7                | 16             |       8.4 |                    2.5 |        3.3 |   3e-05   |      20 |
- | perl -e1 (baseline) | 0.87                         | 4.2                | 16             |       5.9 |                    0   |        4.7 | 1.2e-05   |      21 |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Sort::Key::Natural  | 1.4                          | 4.8                | 19             |      27   |                   21.6 |        1   |   6e-05 |      20 |
+ | Sort::Naturally::XS | 1.4                          | 4.7                | 19             |      12   |                    6.6 |        2.3 | 1.5e-05 |      21 |
+ | Sort::Naturally     | 1.2                          | 4.7                | 16             |      11   |                    5.6 |        2.4 | 4.4e-05 |      20 |
+ | Sort::Sub           | 1.2                          | 4.7                | 16             |       7.9 |                    2.5 |        3.4 |   2e-05 |      20 |
+ | perl -e1 (baseline) | 0.87                         | 4.2                | 16             |       5.4 |                    0   |        5   |   1e-05 |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
