@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::SortSub::naturally;
 
-our $VERSION = 0.004; # VERSION
+our $VERSION = 0.005; # VERSION
 
 our $results = [
   [
@@ -8,52 +8,52 @@ our $results = [
     "OK",
     [
       {
-        errors => 4.3e-07,
+        errors => 9.1e-07,
         participant => "Sort::Naturally::nsort",
-        rate => 644,
+        rate => 578,
         samples => 20,
-        time => 1.55,
+        time => 1.73,
         vs_slowest => 1,
       },
       {
-        errors => 2.1e-07,
+        errors => 5.9e-06,
         participant => "Sort::Key::Natural::natsort",
-        rate => 2070,
+        rate => 2000,
         samples => 20,
-        time => 0.483,
-        vs_slowest => 3.21,
+        time => 0.5,
+        vs_slowest => 3,
       },
       {
-        errors => 6.7e-06,
+        errors => 4.7e-08,
         participant => "Sort::Naturally::XS::nsort",
-        rate => 6000,
-        samples => 20,
-        time => 0.2,
-        vs_slowest => 9,
+        rate => 7950,
+        samples => 26,
+        time => 0.126,
+        vs_slowest => 13.8,
       },
       {
-        errors => 1.2e-11,
+        errors => 8.4e-08,
         participant => "Sort::Sub::naturally",
-        rate => 231720,
-        samples => 20,
-        time => 0.0043156,
-        vs_slowest => 359.54,
+        rate => 200000,
+        samples => 31,
+        time => 0.005,
+        vs_slowest => 400,
       },
       {
-        errors => 1.5e-09,
-        participant => "Sort::Naturally::ncmp",
-        rate => 234000,
-        samples => 24,
-        time => 0.00427,
-        vs_slowest => 363,
-      },
-      {
-        errors => 1.5e-09,
+        errors => 4.6e-11,
         participant => "Sort::Naturally::XS::ncmp",
-        rate => 236000,
-        samples => 24,
-        time => 0.00424,
-        vs_slowest => 366,
+        rate => 233800,
+        samples => 20,
+        time => 0.004277,
+        vs_slowest => 404.5,
+      },
+      {
+        errors => 1.7e-09,
+        participant => "Sort::Naturally::ncmp",
+        rate => 235000,
+        samples => 20,
+        time => 0.00426,
+        vs_slowest => 406,
       },
     ],
     {
@@ -176,7 +176,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2882.359,
+                                              speed                        => "2600.500",
                                               stepping                     => 4,
                                             },
                                             {
@@ -291,7 +291,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2853.921,
+                                              speed                        => 2874.648,
                                               stepping                     => 4,
                                             },
                                             {
@@ -406,7 +406,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2877.273,
+                                              speed                        => 2838.171,
                                               stepping                     => 4,
                                             },
                                             {
@@ -521,11 +521,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2600.062,
+                                              speed                        => 2867.375,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.390017986297607,
+      "func.elapsed_time"              => 0.346285104751587,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                           => 1.034,
@@ -566,13 +566,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::SortSub::naturally",
-      "func.scenario_module_md5sum"    => "e37fb7a039b0a5dfbc48a6159a897530",
-      "func.scenario_module_mtime"     => 1486010466,
-      "func.scenario_module_sha1sum"   => "54d75c656f1d0974bcf65f11230221573b300eb5",
-      "func.scenario_module_sha256sum" => "bb9d55242143c338b5c63ae7c40ceb9b176efb94082bb388e73035784bbbc161",
-      "func.time_end"                  => 1486010613.2003,
+      "func.scenario_module_md5sum"    => "aa87f93d960b7e72c08d420d8e111db8",
+      "func.scenario_module_mtime"     => 1486010934,
+      "func.scenario_module_sha1sum"   => "c536459b12812c2fdec9bdde0b4669fd77e6141f",
+      "func.scenario_module_sha256sum" => "e1b00f5ae199376ff30b311460806574050fdff304f8965a9f8fe108e76d3775",
+      "func.time_end"                  => 1486010957.25481,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1486010612.81028,
+      "func.time_start"                => 1486010956.90853,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ms"],
       "table.fields"                   => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
@@ -583,52 +583,52 @@ our $results = [
     "OK",
     [
       {
-        errors => 0,
+        errors => 1.1e-07,
         participant => "Sort::Naturally::nsort",
-        rate => 14336.6,
-        samples => 21,
-        time => 69.7516,
+        rate => 15000,
+        samples => 20,
+        time => 65,
         vs_slowest => 1,
       },
       {
-        errors => 1.3e-08,
+        errors => 8e-08,
         participant => "Sort::Key::Natural::natsort",
-        rate => 20700,
+        rate => 18000,
         samples => 20,
-        time => 48.4,
-        vs_slowest => 1.44,
+        time => 55,
+        vs_slowest => 1.2,
       },
       {
-        errors => 0,
+        errors => 1.2e-11,
         participant => "Sort::Naturally::XS::nsort",
-        rate => 175698,
+        rate => 189260,
+        samples => 24,
+        time => 5.2838,
+        vs_slowest => 12.278,
+      },
+      {
+        errors => 2e-10,
+        participant => "Sort::Naturally::ncmp",
+        rate => 1580000,
         samples => 21,
-        time => 5.69157,
-        vs_slowest => 12.2553,
+        time => 0.633,
+        vs_slowest => 103,
       },
       {
         errors => 0,
         participant => "Sort::Sub::naturally",
-        rate => 1780320,
+        rate => 1768950,
         samples => 20,
-        time => 0.561697,
-        vs_slowest => 124.18,
+        time => 0.565308,
+        vs_slowest => 114.758,
       },
       {
-        errors => 0,
-        participant => "Sort::Naturally::ncmp",
-        rate => 1780610,
-        samples => 20,
-        time => 0.561605,
-        vs_slowest => 124.201,
-      },
-      {
-        errors => 0,
+        errors => 4.1e-11,
         participant => "Sort::Naturally::XS::ncmp",
-        rate => 1793190,
+        rate => 1794000,
         samples => 20,
-        time => 0.557666,
-        vs_slowest => 125.078,
+        time => 0.5576,
+        vs_slowest => 116.4,
       },
     ],
     {
@@ -751,7 +751,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2882.359,
+                                              speed                        => "2600.500",
                                               stepping                     => 4,
                                             },
                                             {
@@ -866,7 +866,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2853.921,
+                                              speed                        => 2874.648,
                                               stepping                     => 4,
                                             },
                                             {
@@ -981,7 +981,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2877.273,
+                                              speed                        => 2838.171,
                                               stepping                     => 4,
                                             },
                                             {
@@ -1096,11 +1096,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2600.062,
+                                              speed                        => 2867.375,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.390017986297607,
+      "func.elapsed_time"              => 0.346285104751587,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                           => 1.034,
@@ -1141,13 +1141,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::SortSub::naturally",
-      "func.scenario_module_md5sum"    => "e37fb7a039b0a5dfbc48a6159a897530",
-      "func.scenario_module_mtime"     => 1486010466,
-      "func.scenario_module_sha1sum"   => "54d75c656f1d0974bcf65f11230221573b300eb5",
-      "func.scenario_module_sha256sum" => "bb9d55242143c338b5c63ae7c40ceb9b176efb94082bb388e73035784bbbc161",
-      "func.time_end"                  => 1486010613.2003,
+      "func.scenario_module_md5sum"    => "aa87f93d960b7e72c08d420d8e111db8",
+      "func.scenario_module_mtime"     => 1486010934,
+      "func.scenario_module_sha1sum"   => "c536459b12812c2fdec9bdde0b4669fd77e6141f",
+      "func.scenario_module_sha256sum" => "e1b00f5ae199376ff30b311460806574050fdff304f8965a9f8fe108e76d3775",
+      "func.time_end"                  => 1486010957.25481,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1486010612.81028,
+      "func.time_start"                => 1486010956.90853,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "\x{3BC}s"],
       "table.fields"                   => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
